==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GridSelectedCellsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedCellsChangedEventArgsDescription } from "./GridSelectedCellsChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSelectedCellsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridSelectedCellsChangedEventArgsDescriptionMetadata, _super);
    function GridSelectedCellsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSelectedCellsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSelectedCellsChangedEventArgsDescriptionMetadata.a == null) {
            GridSelectedCellsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSelectedCellsChangedEventArgsDescriptionMetadata.c(GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(GridSelectedCellsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedCellsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("CurrentCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
        a.item("AddedCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
        a.item("RemovedCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
    };
    GridSelectedCellsChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSelectedCellsChangedEventArgsDescriptionMetadata.b(a);
        a.ac("GridSelectedCellsChangedEventArgs", function () { return new GridSelectedCellsChangedEventArgsDescription(); });
        a.ab("GridSelectedCellsChangedEventArgs", GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedCellsChangedEventArgsDescriptionMetadata.$t = markType(GridSelectedCellsChangedEventArgsDescriptionMetadata, 'GridSelectedCellsChangedEventArgsDescriptionMetadata');
    GridSelectedCellsChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedCellsChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSelectedCellsChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/GridSelectedCellsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedCellsChangedEventArgsDescription } from "./GridSelectedCellsChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSelectedCellsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridSelectedCellsChangedEventArgsDescriptionMetadata, _super);
    function GridSelectedCellsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSelectedCellsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSelectedCellsChangedEventArgsDescriptionMetadata.a == null) {
            GridSelectedCellsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSelectedCellsChangedEventArgsDescriptionMetadata.c(GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(GridSelectedCellsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedCellsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("CurrentCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
        a.item("AddedCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
        a.item("RemovedCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
    };
    GridSelectedCellsChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSelectedCellsChangedEventArgsDescriptionMetadata.b(a);
        a.ae("GridSelectedCellsChangedEventArgs", function () { return new GridSelectedCellsChangedEventArgsDescription(); });
        a.ad("GridSelectedCellsChangedEventArgs", GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedCellsChangedEventArgsDescriptionMetadata.$t = markType(GridSelectedCellsChangedEventArgsDescriptionMetadata, 'GridSelectedCellsChangedEventArgsDescriptionMetadata');
    GridSelectedCellsChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedCellsChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSelectedCellsChangedEventArgsDescriptionMetadata };
